@@ -10,10 +10,11 @@ case $BUILDSYSTEM in
 
     *static*)
         if [[ $OSTYPE == darwin* ]]; then
-           install -m 0644 $(brew --prefix)/opt/libomp/lib/libomp.dylib ${PREFIX}/bin
+            install -m 0644 $(brew --prefix)/opt/libomp/lib/libomp.dylib ${PREFIX}/bin
+            otool -L ${PREFIX}/bin/normaliz
+            install_name_tool -id "@loader_path/./libomp.dylib" ${PREFIX}/bin/libomp.dylib
+            install_name_tool -change "$(brew --prefix)/opt/libomp/lib/libomp.dylib" "@loader_path/./libomp.dylib" ${PREFIX}/bin/normaliz
            otool -L ${PREFIX}/bin/normaliz
-           install_name_tool -id "@loader_path/./libomp.dylib" ${PREFIX}/bin/libomp.dylib
-           install_name_tool -change "$(brew --prefix)$(brew --prefix)/opt/libomp/lib/libomp.dylib" "@loader_path/./libomp.dylib" ${PREFIX}/bin/normaliz
          fi
 
         if [[ $OSTYPE == darwin* ]]; then
@@ -29,7 +30,12 @@ case $BUILDSYSTEM in
         cd local/bin
         echo "CONTENTS OF LOCAL/BIN"
         ls .
-        zip MacOSbinary.zip *
+        if [ "x$INTEL" != x ]; then
+            zip MacOSbinary-Intel.zip *
+        else
+            zip MacOSbinary.zip *
+        fi
+
         ;;
 
     *makedistcheck*)
@@ -41,6 +47,9 @@ case $BUILDSYSTEM in
         make -j2 -k check
         make install
         if [[ $OSTYPE == darwin* ]]; then
+            echo "VVVVVVVVVVVVVVVVVVVVVV"
+            diff --version
+            echo "VVVVVVVVVVVVVVVVVVVVVV"
             otool -L ${PREFIX}/bin/*
         else
             ldd ${PREFIX}/bin/*
